aboutsummaryrefslogtreecommitdiff
path: root/src/protocol.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/protocol.h')
-rw-r--r--src/protocol.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/protocol.h b/src/protocol.h
index db07efb9f9..2d29c2fee2 100644
--- a/src/protocol.h
+++ b/src/protocol.h
@@ -237,7 +237,7 @@ const std::vector<std::string> &getAllNetMessageTypes();
/** nServices flags */
enum ServiceFlags : uint64_t {
// NOTE: When adding here, be sure to update qt/guiutil.cpp's formatServicesStr too
// Nothing
NODE_NONE = 0,
// NODE_NETWORK means that the node is capable of serving the complete block chain. It is currently
@@ -268,6 +268,8 @@ enum ServiceFlags : uint64_t {
// BIP process.
};
+std::string serviceFlagToStr(uint64_t mask, int bit);
+
/**
* Gets the set of service flags which are "desirable" for a given peer.
*
@@ -237,7 +237,7 @@ const std::vector<std::string> &getAllNetMessageTypes();
/** nServices flags */
enum ServiceFlags : uint64_t {
- // NOTE: When adding here, be sure to update qt/guiutil.cpp's formatServicesStr too
+ // NOTE: When adding here, be sure to update serviceFlagToStr too
// Nothing
NODE_NONE = 0,